Использование — Документация django-ulogin 0.3.0

# Использование

## Быстрый старт

Для использования приложения достаточно в любом месте шаблона вставить подключение шаблонной библиотеки `ulogin_tags` и вызов тега `ulogin_widget`.

    {% load ulogin_tags %}
    {% ulogin_widget %}

На месте тега `ulogin_widget` при рендеринге появится код интеграции dашего сайта c uLogin.

Тег `{% ulogin_widget %}` принимает один необязательный аргумент — `scheme_name`, который указывает на имя используемой схемы настроек.

    {% ulogin_widget "scheme_name" %}

Использование различных схем особенно удобно, если нужно на одной странице разместить несколько виджетов, обладающих различными настройками.